# Releasing the CLI
1. Head over to https://deploy.storyscript.io
2. Run the **`create tag`** build configuration under the **Storyscript Cloud CLI** project
3. As a mandatory requirement, you'll be required to mention the name of the tag
- The name of the tag is the next version following the semver scheme - see the latest release on GitHub
4. Once the build completes, create a GitHub release for the newly added tag

## Friendly URLs
**`create_tag`** build configuration: https://deploy.storyscript.io/buildConfiguration/StoryscriptCloudCli_CreateTag

## Done!
